package jobqueue

import (
	"gorm.io/gorm"
	"time"
)

type JobLog struct {
	LogID         uint          `gorm:"primarykey;autoIncrement:true"`
	JobID         JobID         `json:"job_id" gorm:"type:varchar(255);foreignKey:JobID;references:ID"`
	ProcessID     int           `json:"process_id"`
	StartTime     time.Time     `json:"start_time"`
	EndTime       time.Time     `json:"end_time"`
	ExitCode      int           `json:"exit_code"`
	Result        string        `json:"output" gorm:"type:TEXT"` // Assuming serialized JSON for any type
	ResourceUsage ResourceUsage `json:"resource_usage" gorm:"embedded;embeddedPrefix:resource_usage_"`
	IO            IO            `json:"io" gorm:"embedded;embeddedPrefix:io_"`
	ErrorMsg      string        `json:"error_msg"`
	IsSuccessful  bool          `json:"is_successful"`

	CreatedAt time.Time
	UpdatedAt time.Time
	DeletedAt gorm.DeletedAt `gorm:"index"`
}

type ResourceUsage struct {
	Memory uint64  `json:"memory"`
	CPU    float64 `json:"cpu"`
}

type IO struct {
	Disk    int64 `json:"disk"`
	Network int64 `json:"network"`
}

func (JobLog) TableName() string {
	return globalTableNamePrefix + "job_logs"
}
